﻿using System;
using System.Globalization;
using System.Windows.Controls;
using System.Windows.Data;
using Delay;

namespace GroupingItemsControlConverterSample
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            // Populate list with some random animals
            DataContext = new Animal[]
            {
                new Animal("Dory", "Fish"),
                new Animal("Felix", "Cat"),
                new Animal("Fluffy", "Dog"),
                new Animal("Jake", "Snake"),
                new Animal("Mittens", "Cat"),
                new Animal("Myrtle", "Turtle"),
                new Animal("Nemo", "Fish"),
                new Animal("Rex", "Dog"),
                new Animal("Rover", "Dog"),
                new Animal("Toonces", "Cat"),
            };
        }
    }

    // Data class
    public class Animal
    {
        public string Name { get; private set; }
        public string Species { get; private set; }
        public Animal(string name, string species)
        {
            Name = name;
            Species = species;
        }
    }

    // Simple IGroupingItemsControlConverterSelector implementation for grouping by an Animal's species
    public class AnimalSpeciesGroupSelector : IGroupingItemsControlConverterSelector
    {
        public Func<object, IComparable> GetGroupSelector()
        {
            return (o) => ((Animal)o).Species;
        }
    }

    // Simple IValueConverter implementation for disabling non-Animal UI elements (i.e., group headers)
    public class IsAnimalConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var contentControl = value as ContentControl;
            return (null != contentControl) && contentControl.Content is Animal;
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
